pub struct Quantitative<T: QuantitativeLimit> { /* private fields */ }Expand description
Quantitative domain.
Implementations
Sourceimpl<T: QuantitativeLimit + Copy> Quantitative<T>
impl<T: QuantitativeLimit + Copy> Quantitative<T>
Sourcepub fn new(inf: T, sup: T) -> Result<Self, QuantitativeError<T>>
pub fn new(inf: T, sup: T) -> Result<Self, QuantitativeError<T>>
Quantitative domain constructor.
Arguments
inf: Domain inferior limit.sup: Domain superior limit.
Examples
/// Different inf & sup values
assert!(Quantitative::new(-1, 3).is_ok());
/// Equals inf & sup values
assert!(Quantitative::new(-1, -1).is_ok());
/// Float values
assert!(Quantitative::new(-1.3, -1.2).is_ok());Errors
QuantitativeError::InvalidRange: If inf > sup.
assert_eq!(
Quantitative::new(10, 5),
Err(QuantitativeError::InvalidRange { inf: 10, sup: 5 })
);Sourcepub fn inf(&self) -> T
pub fn inf(&self) -> T
Returns domain inferior limit.
Examples
let inf = -1;
let domain = Quantitative::new(inf, 0).unwrap();
assert_eq!(domain.inf(), inf);Sourcepub fn sup(&self) -> T
pub fn sup(&self) -> T
Returns domain superior limit.
Examples
let sup = 3.4;
let domain = Quantitative::new(0.0, sup).unwrap();
assert_eq!(domain.sup(), sup);Sourcepub fn valid_assessment(&self, value: T) -> bool
pub fn valid_assessment(&self, value: T) -> bool
Check if a given value is a valid assessment in the current domain.
Arguments
value: Value to be checked.
Examples
let inf = -1.3;
let sup = inf + 1.0;
let domain = Quantitative::new(inf, sup).unwrap();
for (v, e) in [
(inf, true),
(sup, true),
(inf + 0.1, true),
(sup - 0.1, true),
(inf - 0.1, false),
(sup + 0.1, false),
] {
assert_eq!(domain.valid_assessment(v), e);
}Sourcepub fn intersection(&self, other: &Self) -> Option<Self>
pub fn intersection(&self, other: &Self) -> Option<Self>
Computes intersection with other interval.
Arguments
other: Interval with which compute the intersection.
Examples
let domain = Quantitative::new(0.0, 1.0).unwrap();
for (inf, sup, expected) in [
(0.0, 1.0, Some(Quantitative::new(0.0, 1.0).unwrap())),
(0.5, 1.0, Some(Quantitative::new(0.5, 1.0).unwrap())),
(1.0, 1.5, None),
(-1.0, 0.0, None),
(-1.0, 0.5, Some(Quantitative::new(0.0, 0.5).unwrap())),
(-1.0, 2.0, Some(Quantitative::new(0.0, 1.0).unwrap())),
(0.25, 0.75, Some(Quantitative::new(0.25, 0.75).unwrap()))
] {
let other = Quantitative::new(inf, sup).unwrap();
assert_eq!(domain.intersection(&other), expected);
}Sourcepub fn difference(&self, other: &Self) -> Vec<Self>
pub fn difference(&self, other: &Self) -> Vec<Self>
Computes intersection with other interval.
Arguments
other: Interval with which compute the intersection.
Examples
let domain = Quantitative::new(0.0, 1.0).unwrap();
for (inf, sup, expected) in [
(0.0, 1.0, vec![]),
(0.5, 1.0, vec![Quantitative::new(0.0, 0.5).unwrap()]),
(0.5, 1.5, vec![Quantitative::new(0.0, 0.5).unwrap()]),
(1.0, 1.5, vec![Quantitative::new(0.0, 1.0).unwrap()]),
(-1.0, 0.0, vec![Quantitative::new(0.0, 1.0).unwrap()]),
(-1.0, 0.5, vec![Quantitative::new(0.5, 1.0).unwrap()]),
(-1.0, 2.0, vec![]),
(0.25, 0.75, vec![Quantitative::new(0.0, 0.25).unwrap(), Quantitative::new(0.75, 1.0).unwrap()])
] {
let other = Quantitative::new(inf, sup).unwrap();
assert_eq!(domain.difference(&other), expected);
}Trait Implementations
Sourceimpl<T: Clone + QuantitativeLimit> Clone for Quantitative<T>
impl<T: Clone + QuantitativeLimit> Clone for Quantitative<T>
Sourcefn clone(&self) -> Quantitative<T>
fn clone(&self) -> Quantitative<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug + QuantitativeLimit> Debug for Quantitative<T>
impl<T: Debug + QuantitativeLimit> Debug for Quantitative<T>
Sourceimpl<T: Hash + QuantitativeLimit> Hash for Quantitative<T>
impl<T: Hash + QuantitativeLimit> Hash for Quantitative<T>
Sourceimpl<T: PartialEq + QuantitativeLimit> PartialEq for Quantitative<T>
impl<T: PartialEq + QuantitativeLimit> PartialEq for Quantitative<T>
Sourcefn eq(&self, other: &Quantitative<T>) -> bool
fn eq(&self, other: &Quantitative<T>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<T: QuantitativeLimit> Domain for Quantitative<T>
impl<T: Eq + QuantitativeLimit> Eq for Quantitative<T>
impl<T: QuantitativeLimit> StructuralPartialEq for Quantitative<T>