Interval

Struct Interval 

pub struct Interval<'domain, T: QuantitativeLimit> { /* private fields */ }
Interval valuation.

Implementations

Source

impl<'domain, T: QuantitativeLimit + Copy + Debug + Display + Into<f64> + Add<Output = T> + Sub<Output = T>> Interval<'domain, T>

pub fn new( domain: &'domain Quantitative<T>, min: T, max: T, ) -> Result<Self, IntervalError<T>>

Creates a new valuation.

Arguments
  • domain: A quantitative domain reference.
  • min: Interval min value.
  • max: Interval max value.
Examples
let domain = Quantitative::new(1, 5).unwrap();
assert!(Interval::new(&domain, 2, 3).is_ok());
let domain = Quantitative::new(1.2, 5.7).unwrap();
assert!(Interval::new(&domain, 2.3, 2.7).is_ok());
Errors

IntervalError::InvalidMin: If min < domain inferior limit.

let domain = Quantitative::new(1, 5).unwrap();
assert_eq!(
    Interval::new(&domain, 0, 3),
    Err(IntervalError::InvalidMin { min: 0, inf: 1 })
);

IntervalError::InvalidMax: If max > domain superior limit.

let domain = Quantitative::new(1, 5).unwrap();
assert_eq!(
    Interval::new(&domain, 2, 6),
    Err(IntervalError::InvalidMax { max: 6, sup: 5 })
);

IntervalError::InvalidRange: If min > max.

let domain = Quantitative::new(1, 5).unwrap();
assert_eq!(
    Interval::new(&domain, 3, 2),
    Err(IntervalError::InvalidRange { min: 3, max: 2 })
);
pub fn value(&self) -> (T, T)

Returns valuation values.

Examples
let domain = Quantitative::new(1, 5).unwrap();
let valuation = Interval::new(&domain, 2, 3).unwrap();
assert_eq!(valuation.value(), (2, 3));
let domain = Quantitative::new(1.0, 5.7).unwrap();
let valuation = Interval::new(&domain, 2.0, 3.0).unwrap();
assert_eq!(valuation.value(), (2.0, 3.0));
pub fn domain(&self) -> &'domain Quantitative<T>

Returns valuation domain.

Examples
let domain = Quantitative::new(1.0, 5.7).unwrap();
let valuation = Interval::new(&domain, 2.0, 3.0).unwrap();
assert_eq!(*valuation.domain(), domain);
pub fn normalize(&self) -> Interval<'_, f64>

Value normalized in domain 0.0 to 1.0.

Note that the type of value is f64.

Examples
let domain = Quantitative::new(0.0, 10.0).unwrap();
let valuation = Interval::new(&domain, 2.0, 3.5).unwrap();
let normalized = valuation.normalize();
assert_eq!(normalized.value(), (0.2, 0.35));
assert_eq!(*normalized.domain(), NORMALIZATION_DOMAIN);

let domain = Quantitative::new(-1, 5).unwrap();
let valuation = Interval::new(&domain, 2, 5).unwrap();
let normalized = valuation.normalize();
assert_eq!(normalized.value(), (0.5, 1.0));
assert_eq!(*normalized.domain(), NORMALIZATION_DOMAIN);
pub fn neg(&self) -> Self

Valuation negation.

Examples
let domain = Quantitative::new(0, 10).unwrap();
let valuation = Interval::new(&domain, 2, 4).unwrap();
let neg = valuation.neg();
assert_eq!(neg.value(), (6, 8));
Source

impl<'domain> Interval<'domain, f64>

pub fn resume(&self) -> f64

Source

impl<'domain> Interval<'domain, f32>

pub fn resume(&self) -> f32

Source

impl<'domain> Interval<'domain, i32>

pub fn resume(&self) -> i32

Source

impl<'domain, T> Interval<'domain, T>
where T: Mul<Output = T> + Add<Output = T> + Sub<Output = T> + Div<Output = T> + QuantitativeLimit + Into<f64>,

pub fn unification( &self, domain: &'domain Qualitative<Trapezoidal>, ) -> Result<Unified<'_>, UnifiedError<'_>>

Unification of a Interval valuation in a given domain.

Arguments
  • domain: Domain in which perform the unification.
Examples
let domain = Quantitative::new(0, 7).unwrap();
let unification_domain = qualitative_symmetric_domain!["a", "b", "c", "d", "e"].unwrap();

let valuation = Interval::new(&domain, 5, 6).unwrap();
let unified = valuation.unification(&unification_domain).unwrap();
let measures = unified.measures();
let expected_measures =  vec![0.0, 0.0, 0.14, 1.0, 0.43];
for i in 0..(expected_measures.len()) {
    assert!(
        utilities::math::approx_equal_f32(
            measures[i],
            expected_measures[i],
            2
        ),
        "({}) Value {:.2} vs. Expected {:.2}",
        i,
        measures[i],
        expected_measures[i]
    );
}
Errors

UnifiedError::NonBLTSDomain: If domain is a Non-BLTS domain.

let domain = Quantitative::new(0, 7).unwrap();
let unification_domain = qualitative_symmetric_domain!["a", "b", "c", "d"].unwrap();

let valuation = Interval::new(&domain, 5, 6).unwrap();
assert_eq!(
    valuation.unification(&unification_domain),
    Err(UnifiedError::NonBLTSDomain { domain: &unification_domain })
);
pub fn transform_in_domain( &self, domain: &'domain Quantitative<T>, ) -> Interval<'_, T>

Transform a Interval valuation using a different domain.

Note that domain type should be equal to valuation type.

Arguments
  • domain: Domain to be used.
Examples
let domain = Quantitative::new(0, 7).unwrap();
let transform_domain = Quantitative::new(0, 3).unwrap();

let valuation = Interval::new(&domain, 5, 6).unwrap();
let unified = valuation.transform_in_domain(&transform_domain);
assert_eq!(unified.value(), (2, 2));